/* -------------------------------------------------------------------
 *	$Id: mgd77magref.h,v 1.10 2008/03/27 06:50:54 guru Exp $	
 *      See COPYING file for copying and redistribution conditions.
 *
 *    Copyright (c) 2005-2008 by P. Wessel and M. T. Chandler
 *	File:	mgd77magref.h
 *
 *	MGD77 Magnetic Reference Fields for mgd77sniffer
 *
 *	Authors:
 *		Michael Chandler and Paul Wessel
 *		School of Ocean and Earth Science and Technology
 *		University of Hawaii
 * 
 *	Date:	1-Aug-2005
 * 
 *  References:
 *    Langel, R. A., 1987. The Main Field. In Geomagnetism, Volume I,
 *      (Ed. J. A. Jacobs). London: Academic Press, pp249-512.
 *
 * ------------------------------------------------------------------*/
/*		  Field,		Code,	Start,		End */
		{"Unused",      0,      9999,       9999},
		{"AWC 70",		1,		1965,		1970},
		{"AWC 75",		2,		1967,		1974},
		{"IGRF-65",		3,		1965,		1970},
		{"IGRF-75",		4,		1975,		1980},
		{"GSFC-1266",	5,		1900,		1966},
		{"GSFC-0674",	6,		9999,		9999},
		{"UK 75",		7,		1970,		1975},
		{"POGO 0368",	8,		1965,		1968},
		{"POGO 1068",	9,		1965,		1968},
		{"POGO 0869",	10,		1965,		1968},
		{"IGRF-80",		11,		1980,		1985},
		{"IGRF-85",		12,		1985,		1990},
		{"IGRF-90",		13,		1990,		1995},
		{"IGRF-95",		14,		1995,		2000},
		{"Other",       88,     9999,       9999}
